@@ -1,5 +1,5 @@
 #!/bin/bash
-for PERL in perl5.12.4 perl5.14.2 perl5.16.0 perl5.18.1; do
+for PERL in perl5.10.1 perl5.12.4 perl5.14.2 perl5.16.0 perl5.18.1; do
   echo -e "\n*** $PERL ***"
 
   $PERL Build.PL &&
